//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/DistributionEditor.cpp
//! @brief     Implements classes DistributionSelector and DistributionEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/DistributionEditor.h"
#include "GUI/Model/Beam/BeamDistributionItem.h"
#include "GUI/Model/Descriptor/DistributionItems.h"
#include "GUI/View/Instrument/DistributionPlot.h"

DistributionEditor::DistributionEditor(const QString& title,
                                       const std::optional<MeanConfig>& mean_config,
                                       GUI::ID::Distributions distributions, QWidget* parent,
                                       BeamDistributionItem* item, bool allow_distr)
    : CollapsibleGroupBox(title, parent, item->expandGroupBox)
{
    auto* layout = new QVBoxLayout;
    body()->setLayout(layout);

    m_selector = new DistributionSelector(mean_config, distributions, this, item, allow_distr);
    layout->addWidget(m_selector);
    layout->setSpacing(50);

    m_plot = new DistributionPlot(this);
    m_plot->setFixedSize(280, 170);
    m_plot->setShowMouseCoords(false);
    layout->addWidget(m_plot);
    layout->addStretch(1);

    connect(m_selector, &DistributionSelector::distributionChanged, this,
            &DistributionEditor::distributionChanged);
    connect(m_selector, &DistributionSelector::distributionChanged, this,
            &DistributionEditor::updatePlot);

    updatePlot();
}

void DistributionEditor::updateData()
{
    m_selector->refresh();
}

void DistributionEditor::updatePlot()
{
    auto* d = m_selector->item()->distributionItem();
    m_plot->setVisible(!dynamic_cast<const DistributionNoneItem*>(d));
    m_plot->setDistItem(d);
    m_plot->plotItem();
}
